Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(47)

Unified Diff: tests/utils/utf_test.dart

Issue 12282038: Remove deprecated string features. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/utils/utf_test.dart
diff --git a/tests/utils/utf_test.dart b/tests/utils/utf_test.dart
index 64417895cefb712ea9c078aa65524297b39380ff..10401a3f03adb522b7848cccd88aa6c79209b89c 100644
--- a/tests/utils/utf_test.dart
+++ b/tests/utils/utf_test.dart
@@ -7,8 +7,8 @@ import 'dart:utf';
main() {
String str = codepointsToString([0x1d537]);
// String.charCodes gives 16-bit code units, but stringToCodepoints gives
// back the original code points.
- Expect.listEquals([0xd835, 0xdd37], str.charCodes);
+ Expect.listEquals([0xd835, 0xdd37], str.codeUnits);
Expect.listEquals([0x1d537], stringToCodepoints(str));
}
@@ -7,8 +7,8 @@ import 'dart:utf';
main() {
String str = codepointsToString([0x1d537]);
- // String.charCodes gives 16-bit code units, but stringToCodepoints gives
+ // String.codeUnits gives 16-bit code units, but stringToCodepoints gives
// back the original code points.

Powered by Google App Engine
This is Rietveld 408576698